@@ -6,7 +6,7 @@ from logging import handlers
 import platform
 
 from Dxr_mqtt.msg import msg
-from Dxr_utils import gvalues as gv
+from Dxr_utils import gvalues
 from Dxr_mqtt.dxr_mqtt import *
 
 isPrintDebug = False
@@ -66,9 +66,9 @@ else:
     err_log = Logger(os.environ['HOME'] + '/log/error.log', level='error')
     debug_log = Logger(os.environ['HOME'] + '/log/debug.log', level='debug')
 
-all_publisher = Dxr_Publisher('/response/log_manager/' + gv.module_name + '/all')
-debug_publisher = Dxr_Publisher('/response/log_manager/' + gv.module_name + '/debug')
-error_publisher = Dxr_Publisher('/response/log_manager/' + gv.module_name + '/error')
+all_publisher = Dxr_Publisher('/response/log_manager/' + gvalues.module_name + '/all')
+debug_publisher = Dxr_Publisher('/response/log_manager/' + gvalues.module_name + '/debug')
+error_publisher = Dxr_Publisher('/response/log_manager/' + gvalues.module_name + '/error')
 
 
 def print_info(log_str):
