@@ -500,8 +500,8 @@ class io_ctrl(msg):
     class msg_class(NestedClass):
         def __init__(self):
             super().__init__()
-            self.priority = ""  # int型
-            self.io = ""  # list型
+            self.sn = ""  # int型
+            self.io = []  # list型
 
     def __init__(self):
         super().__init__()
@@ -524,7 +524,7 @@ class io_ctrl_response(msg):
         }
     }
     """
-    topic = "/io_ctrl_re"
+    topic = "/io_ctrl_response"
 
     class msg_class(NestedClass):
         def __init__(self):
@@ -568,10 +568,8 @@ class get_voltage_response(msg):
     定义一个应用消息,消息结构如下：
     {
         "msg":{
-            "voltage":[17,17],//电池电压,list型
-            "error_code":0,
-            "error_msg":"",
-            "result":1
+            "voltage":[80000,0],//电池1电压，电池2电压,单位mv
+            "current":[1000,0] //电池1电流,电池2电流
         }
     }
     """
@@ -581,9 +579,7 @@ class get_voltage_response(msg):
         def __init__(self):
             super().__init__()
             self.voltage = ""  # list型
-            self.error_code = ""  # int型
-            self.error_msg = ""  # string型
-            self.result = ""  # int型
+            self.current = ""  # list型
 
     def __init__(self):
         super().__init__()
@@ -635,9 +631,13 @@ class get_speed_response(msg):
     topic = "/get_speed_response"
 
     class msg_class(NestedClass):
+        
         def __init__(self):
             super().__init__()
-            self.speed = ""  # dict型
+            self.speed = {
+                "v": "",
+                "w": ""
+                }  # dict型
             self.error_code = ""  # int型
             self.error_msg = ""  # string型
             self.result = ""  # int型
@@ -668,6 +668,7 @@ class get_sensor_response(msg):
             self.collide = ""  # int型
             self.button_stop = ""  # string型
             self.sonic_stop = ""  # int型
+            self.sonic = ""  # list型
 
     def __init__(self):
         super().__init__()
@@ -970,3 +971,258 @@ class set_task_list(msg):
         super().__init__()
         self.data = []
 
+# 启动或关闭跟随功能
+class ctrl_follow(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "sn":"123",//web端发送带sn，服务端转发给客户端不需要sn
+            "action":1 ,//1:启动跟随;0:关闭跟随,int类型
+        }
+    }
+    """
+    topic = "/ctrl_follow"
+
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.sn = ""  # # 只有web端发送带sn，服务端转发给客户端不需要sn
+            self.action = ""  # int型
+
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+
+# 启动或关闭跟随功能返回值
+class ctrl_follow_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "error_code":0,
+            "error_msg":"",
+            "action:0, //结果，0:关闭，1:开启
+            "result":1 //0:失败，1:成功
+        }
+    }
+    """
+    topic = "/ctrl_follow_response"
+
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.error_code = ""  # int型
+            self.error_msg = ""  # string型
+            self.action = ""  # int型
+            self.result = ""  # int型
+
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+        
+# 服务器控制机器人进行音频播放
+class audio_output_play(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {   "task_id":"10000", //任务唯一表示符
+        "msg":{
+            "name":"follow_start", //播放音频名称,string类型
+            "volume":"" //播放音量 0-100,string类型
+        }
+    }
+    """
+    topic = "/audio/output/play"
+
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.name = ""  # string型
+            self.volume = ""  # string型
+
+    def __init__(self):
+        super().__init__()
+        self.task_id = ''
+        self.msg = self.msg_class()  # 消息体
+        
+# 服务器控制机器人进行音频播放返回值
+class audio_output_play_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {   "task_id":"10000", //任务唯一表示符
+        "msg":{
+            "error_code": 0, //出错代码
+            "error_msg": "", //出错信息
+            "result": 1 //结果 0:失败,1:成功
+        }
+    }
+    """
+    topic = "/audio/output/play_response"
+
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.error_code = ""  # string型
+            self.error_msg = ""  # string型
+            self.result = ""  # string型
+
+    def __init__(self):
+        super().__init__()
+        self.task_id = ''
+        self.msg = self.msg_class()  # 消息体
+
+# 读取或写入单板硬件配置信息
+class hardware_ctrl(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        {
+            "priority": 0, //优先级0-5 遥操作:0 跟随:1 自主导航:2 其它:3
+            "msg":{
+                "Mode":1, //uint8_t,操作模式 0:读取 1:写入
+                "MaxRPM":1, //uint16_t,电机最高转速 RPM
+                "DriverType":1, //uint8_t,控制指令：0x00:惠斯通 0x01:拓达 0x02:中菱
+                "ChassisType":1, //uint8_t,底盘类型
+                "VoltageType":1, //uint8_t,电压表类型 0:电压表 1:速遥电池 2:RS485电压模块
+                "UltrasonicType":1, //uint8_t,超声类型 104:KS104 136:KS136A
+                "FrontNumber":1, //uint8_t,前侧超声数量
+                "BackNumber":1, //uint8_t,后侧超声数量
+                "SideNumber":1, //uint8_t,左右侧超声数量
+                "GearBoxDirection":1, //uint8_t,减速器转向 0:反向 1:正向
+            }
+        }
+    }
+    """
+    topic = "/hardware_ctrl"
+
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.Mode = ""  # uint8_t,
+            self.MaxRPM = ""  # uint16_t,
+            self.DriverType = ""  # uint8_t,
+            self.ChassisType = ""  # uint8_t,
+            self.VoltageType = ""  # uint8_t,
+            self.UltrasonicType = ""  # uint8_t,
+            self.FrontNumber = ""  # uint8_t,
+            self.BackNumber = ""  # uint8_t,
+            self.SideNumber = ""  # uint8_t,
+            self.GearBoxDirection = ""  # uint8_t,
+            
+    def __init__(self):
+        super().__init__()
+        self.priority = ""  
+        self.msg = self.msg_class()  # 消息体
+
+# 读取或写入单板硬件配置信息返回值
+class hardware_ctrl_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        {
+            "msg":{
+                "Mode":1, //uint8_t,操作模式 0:读取 1:写入
+                "MaxRPM":1, //uint16_t,电机最高转速 RPM
+                "DriverType":0x00, //uint8_t,控制指令：0x00:惠斯通 0x01:拓达 0x02:中菱
+                "ChassisType":1, //uint8_t,底盘类型
+                "VoltageType":1, //uint8_t,电压表类型 0:电压表 1:速遥电池 2:RS485电压模块
+                "UltrasonicType":104, //uint8_t,超声类型 104:KS104 136:KS136A
+                "FrontNumber":1, //uint8_t,前侧超声数量
+                "BackNumber":1, //uint8_t,后侧超声数量
+                "SideNumber":1, //uint8_t,左右侧超声数量
+                "GearBoxDirection":1, //uint8_t,减速器转向 0:反向 1:正向
+            }
+        }
+    }
+    """
+    topic = "/hardware_ctrl_response"
+
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.Mode = ""  # uint8_t,
+            self.MaxRPM = ""  # uint16_t,
+            self.DriverType = ""  # uint8_t,
+            self.ChassisType = ""  # uint8_t,
+            self.VoltageType = ""  # uint8_t,
+            self.UltrasonicType = ""  # uint8_t,
+            self.FrontNumber = ""  # uint8_t,
+            self.BackNumber = ""  # uint8_t,
+            self.SideNumber = ""  # uint8_t,
+            self.GearBoxDirection = ""  # uint8_t,
+            
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+        
+#获取跟随运动参数
+class get_navigation_info(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+    }
+    """
+    topic = "/get_navigation_info"
+
+    def __init__(self):
+        super().__init__()
+        
+#获取跟随运动参数返回值
+class get_navigation_info_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "move_speed_v":1.0, //最大速度,float型
+            "move_speed_w":1.0, //最大角速度,float型
+            "follow_dis":1.0, //跟随距离,float型
+            "result":1, //跟随状态,0:未开启,1:已开启,2:错误,int型
+            "error_msg":"" //错误信息,string型
+        }
+    }
+    """
+    topic = "/get_navigation_info_response"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.move_speed_v = ""  # float型
+            self.move_speed_w = ""  # float型
+            self.follow_dis = ""  # float型
+            self.result = ""  # float型
+            self.error_msg = ""  # float型
+            
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+        
+#服务器控制机器人云台进行运动
+class actuator_ptz_control(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "status":"",//状态String
+            "isPreset":"",//是否设置到预置点Int
+            "preset_state":"",//当前预置位状态Byte
+            "cam_ex_code:"",//云台异常代码Int
+            "x":"", //云台水平轴转动到指定角度;0:初始点;
+            "y":"" //云台垂直轴转动到指定角度;0:初始点;
+        }
+    }
+    """
+    topic = "/actuator/ptz/control"
+    
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.status = ""  # String型
+            self.isPreset = ""  # Int型
+            self.preset_state = ""  # Byte型
+            self.cam_ex_code = ""  # Int型
+            self.x = ""  # Int型
+            self.y = ""  # Int型
+            
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
